psychopy_ext.exp.Task.set_autorun — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.set_autorun

`Task.` `set_autorun`(exp_plan)

  Automatically runs experiment by simulating key responses.

  This is just the absolute minimum for autorunning. Best practice would be extend this function to simulate responses according to your hypothesis.

  Args: | exp_plan (list of dict) A list of trial definitions.
  Returns: | exp_plan with `autoresp` and `autort` columns included.